covid-shared
============

.. image:: https://badge.fury.io/py/covid-shared.svg
    :target: https://badge.fury.io/py/covid-shared

.. image:: https://github.com/ihmeuw/covid-shared/workflows/build/badge.svg?branch=master
    :target: https://github.com/ihmeuw/covid-shared/actions?query=workflow%3Abuild

.. image:: https://zenodo.org/badge/255461232.svg
   :target: https://zenodo.org/badge/latestdoi/255461232

Shared utilities for covid data processing.

Please send all inquiries to covid19@healthdata.org
